use rand::seq::SliceRandom;
use serde_json::Value;
use std::collections::HashSet;
use std::fs::File;
use std::io::BufReader;

fn main() {
    let file = File::open("team_names.json").expect("Unable to open JSON");
    let reader = BufReader::new(file);
    let teams_json: Value = serde_json::from_reader(reader).expect("Unable to parse JSON");

    let team_names_list = teams_json["team_names"].as_array().unwrap();
    let team_colors: Vec<&str> = teams_json["team_colors"]
        .as_array()
        .unwrap()
        .iter()
        .filter_map(|color| color.as_str())
        .collect();

    let mut selected_colors = HashSet::new();
    let mut rng = rand::thread_rng();
    if let Some(chosen_name) = team_names_list.choose(&mut rng) {
        println!("Randomly chosen team name: {}", chosen_name);
    } else {
        println!("No team names available");
    }

    while selected_colors.len() < 3 {
        if let Some(color) = team_colors.choose(&mut rng) {
            selected_colors.insert(*color);
        }
    }

    println!("Randomly selected team colors: ");
    for color in selected_colors {
        println!("- {}", color);
    }
}
